==> cakephp_1.2.0.7296-rc2.orig.tar.gz: cake_1.2.0.7296-rc2/cake/tests/lib/header.php <==
<?php
/* SVN FILE: $Id: header.php 7118 2008-06-04 20:49:29Z gwoo $ */
/**
 * Short description for file.
 *
 * Long description for file
 *
 * PHP versions 4 and 5
 *
 * CakePHP(tm) Tests <https://trac.cakephp.org/wiki/Developement/TestSuite>
 * Copyright 2005-2008, Cake Software Foundation, Inc.
 *								1785 E. Sahara Avenue, Suite 490-204
 *								Las Vegas, Nevada 89104
 *
 *  Licensed under The Open Group Test Suite License
 *  Redistributions of files must retain the above copyright notice.
 *
 * @filesource
 * @copyright		Copyright 2005-2008, Cake Software Foundation, Inc.
 * @link				https://trac.cakephp.org/wiki/Developement/TestSuite CakePHP(tm) Tests
 * @package			cake
 * @subpackage		cake.cake.tests.lib
 * @since			CakePHP(tm) v 1.2.0.4433
 * @version			$Revision: 7118 $
 * @modifiedby		$LastChangedBy: gwoo $
 * @lastmodified	$Date: 2008-06-04 13:49:29 -0700 (Wed, 04 Jun 2008) $
 * @license			http://www.opensource.org/licenses/opengroup.php The Open Group Test Suite License
 */
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
	<head>
		<meta http-equiv='content-Type' content='text/html; <?php echo $characterSet; ?>' />
		<title>CakePHP Test Suite v 1.2.0.0</title>
		<style type="text/css">
			h3 {font-size: 170%; padding-top: 1em}
			a {font-size: 120%}
			li {line-height: 140%}
			.test-menu {float:left; margin-right: 24px;}
			.test-results {float:left; width: 67%;}
			ul.tests {margin: 0; font-size:12px;}
			ul.tests li {list-style: none; margin: 14px 0; padding-left: 20px;}
			ul.tests li span { font-size:14px; text-transform: uppercase; display:block; color: black; font-weight: bold; }
			ul.tests li.pass span, ul.tests li.skipped span { display:inline;}
			ul.tests li.fail span { color: red; }
			ul.tests li.fail {background: url(http://cakephp.org/img/test-fail-icon.png) top left no-repeat}
			ul.tests li.pass {background: url(http://cakephp.org/img/test-pass-icon.png) top left no-repeat;}
			ul.tests li.pass span { color: green; }
			ul.tests li div { margin: 5px 0 8px 0; }
			ul.tests li div.msg { font-weight: bold; }
			#content {overflow: auto}
		</style>
		<link rel="stylesheet" type="text/css" href="<?php echo $baseUrl; ?>css/cake.generic.css" />
	</head>
	<body>
		<div id="container">
			<div id="header">
				<h1>CakePHP: the rapid development php framework</h1>
			</div>
			<div id="content">
			<h2>CakePHP Test Suite v 1.2.0.0</h2>

==> cakephp_1.2.0.7692-rc3.orig.tar.gz: cake_1.2.0.7692-rc3/cake/tests/lib/header.php <==
<?php
/* SVN FILE: $Id: header.php 7690 2008-10-02 04:56:53Z nate $ */
/**
 * Short description for file.
 *
 * Long description for file
 *
 * PHP versions 4 and 5
 *
 * CakePHP(tm) Tests <https://trac.cakephp.org/wiki/Developement/TestSuite>
 * Copyright 2005-2008, Cake Software Foundation, Inc.
 *								1785 E. Sahara Avenue, Suite 490-204
 *								Las Vegas, Nevada 89104
 *
 *  Licensed under The Open Group Test Suite License
 *  Redistributions of files must retain the above copyright notice.
 *
 * @filesource
 * @copyright		Copyright 2005-2008, Cake Software Foundation, Inc.
 * @link				https://trac.cakephp.org/wiki/Developement/TestSuite CakePHP(tm) Tests
 * @package			cake
 * @subpackage		cake.cake.tests.lib
 * @since			CakePHP(tm) v 1.2.0.4433
 * @version			$Revision: 7690 $
 * @modifiedby		$LastChangedBy: nate $
 * @lastmodified	$Date: 2008-10-02 00:56:53 -0400 (Thu, 02 Oct 2008) $
 * @license			http://www.opensource.org/licenses/opengroup.php The Open Group Test Suite License
 */
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
	<head>
		<meta http-equiv='content-Type' content='text/html; <?php echo $characterSet; ?>' />
		<title>CakePHP Test Suite v 1.2.0.0</title>
		<style type="text/css">
			h3 {font-size: 170%; padding-top: 1em}
			a {font-size: 120%}
			li {line-height: 140%}
			.test-menu {float:left; margin-right: 24px;}
			.test-results {float:left; width: 67%;}
			ul.tests {margin: 0; font-size:12px;}
			ul.tests li {list-style: none; margin: 14px 0; padding-left: 20px;}
			ul.tests li span { font-size:14px; text-transform: uppercase; display:block; color: black; font-weight: bold; }
			ul.tests li.pass span, ul.tests li.skipped span { display:inline;}
			ul.tests li.fail span { color: red; }
			ul.tests li.pass span { color: green; }
			ul.tests li.skipped span { color: navy; }
			ul.tests li.fail {background: url(http://cakephp.org/img/test-fail-icon.png) top left no-repeat}
			ul.tests li.pass {background: url(http://cakephp.org/img/test-pass-icon.png) top left no-repeat;}
			ul.tests li.skipped {background: url(http://cakephp.org/img/test-skip-icon.png) top left no-repeat;}
			ul.tests li div { margin: 5px 0 8px 0; }
			ul.tests li div.msg { font-weight: bold; }
		</style>
		<link rel="stylesheet" type="text/css" href="<?php echo $baseUrl; ?>css/cake.generic.css" />
	</head>
	<body>
		<div id="container">
			<div id="header">
				<h1>CakePHP: the rapid development php framework</h1>
			</div>
			<div id="content">
			<h2>CakePHP Test Suite v 1.2.0.0</h2>
